﻿using System;
using System.Configuration;
using System.Diagnostics;

namespace DIConnect {
	class Program {
		// app.config values
		private static string ServerType = ConfigurationManager.AppSettings["ServerType"];
		private static string ServerName = ConfigurationManager.AppSettings["ServerName"];
		private static string DatabaseName = ConfigurationManager.AppSettings["DatabaseName"];
		private static string DatabaseUserName = ConfigurationManager.AppSettings["DatabaseUserName"];
		private static string DatabasePassword = ConfigurationManager.AppSettings["DatabasePassword"];
		private static string SapUserName = ConfigurationManager.AppSettings["SapUserName"];
		private static string SapPassword = ConfigurationManager.AppSettings["SapPassword"];

		static void Main(string[] args) {
			try {
				Console.WriteLine(" Connecting to company...");
				SAPbobsCOM.Company company = ConnectToCompany();
			} catch (Exception ex) {
				Console.WriteLine("   Failed to connect: " + ex.Message);
			}
			Console.ReadKey();
			Console.WriteLine();
			Console.Write(" Exiting... ");
		}

		private static SAPbobsCOM.Company ConnectToCompany() {
			SAPbobsCOM.Company company = new SAPbobsCOM.Company();
			company.Server = ServerName;
			company.CompanyDB = DatabaseName;
			company.UserName = SapUserName;
			company.Password = SapPassword;
			company.UseTrusted = false;
			switch (ServerType) {
				case "HANA": company.DbServerType = SAPbobsCOM.BoDataServerTypes.dst_HANADB; break;
				case "SQL2008": company.DbServerType = SAPbobsCOM.BoDataServerTypes.dst_MSSQL2008; break;
				case "SQL2012": company.DbServerType = SAPbobsCOM.BoDataServerTypes.dst_MSSQL2012; break;
				case "SQL2014": company.DbServerType = SAPbobsCOM.BoDataServerTypes.dst_MSSQL2014; break;
				case "SQL2016": company.DbServerType = SAPbobsCOM.BoDataServerTypes.dst_MSSQL2016; break;
				default: throw new Exception("Invalid ServerType '" + ServerType + "' in app.config");
			}
			company.DbUserName = DatabaseUserName;
			company.DbPassword = DatabasePassword;

            Stopwatch stopwatch = Stopwatch.StartNew();
            int res = company.Connect();
            stopwatch.Stop();
            if (res != 0) {
				int err;
				string error;
				company.GetLastError(out err, out error);
				throw new Exception(" Connection to company failed: " + err.ToString() + " " + error);
			} else {
				Console.WriteLine(" Connection to company successful in" + stopwatch.ElapsedMilliseconds + " ms ");
			}
			return company;
		}
	}
}
